//*-------------------------------------------------------------------
//* Licensed Materials - Property of IBM
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2002
//*
//* US Government Users Restricted Rights - Use, duplication or
//* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
//*
//*-------------------------------------------------------------------
//*
//* The sample contained herein is provided to you "AS IS".
//*
//* It is furnished by IBM as a simple example and has not been thoroughly tested
//* under all conditions.  IBM, therefore, cannot guarantee its reliability,
//* serviceability or functionality.
//*
//*-------------------------------------------------------------------

package com.mycompany.tools.segmentation;

import com.ibm.commerce.exception.ECException;
import com.ibm.commerce.tools.segmentation.SegmentConstants;
import com.ibm.commerce.tools.segmentation.SegmentConstraintListCmdImpl;
import com.ibm.commerce.tools.segmentation.SegmentUtil;
import java.util.Vector;

/**
 * This class implements the SegmentConstraintListCmd interface to
 * provide the task command that generates the HTML necessary for displaying the list of customer
 * profile constraints.
 */
public class MySegmentConstraintListCmdImpl extends SegmentConstraintListCmdImpl
 {
  /**
   * Performs the execution of the command.
   */
  public void performExecute() throws ECException
   {
    super.performExecute();
    _constraintList += getBeverageConstraint();
   }

  /**
   * Construct and populate an instance of the SegmentNotebookDataBean and store it in _segment.
   */
  protected void initializeSegment()
   {
    _segment = new MySegmentNotebookDataBean();
    _segment.setId(_segmentId.toString());
    try
     {
      _segment.populate();
     }
    catch (Exception e)
     {
     }
   }

  /**
   * Get the HTML for the beverage constraint.
   *
   * @return HTML describing the beverage constraint.
   */
  protected String getBeverageConstraint()
   {
    String result = "";
    String op = ((MySegmentNotebookDataBean)_segment).getBeverageOp();
    if (!SegmentConstants.VALUE_DO_NOT_USE.equals(op))
     {
      Vector values = ((MySegmentNotebookDataBean)_segment).getBeverageValues();
      if (values.size() > 0)
       {
        result += "<LI>";
        if (values.size() == 1)
         {
          String message = "The customer's beverage preference must be \"\"{0}\"\".";
          result += SegmentUtil.substitute(message, (String) values.elementAt(0));
         }
        else
         {
          result += "The customer's beverage preference must match one of the following:";
          result += "\n<UL>\n";
          for (int i = 0; i < values.size(); i++)
           {
            result += "<LI>";
            result += values.elementAt(i);
            result += "</LI>\n";
           }
          result += "</UL>\n";
         }
       }
      result += "</LI>\n";
     }
    return result;
   }
 }
