//*-------------------------------------------------------------------
//* Licensed Materials - Property of IBM
//*
//* 5724-A18
//*
//* (c) Copyright IBM Corp. 2002
//*
//* US Government Users Restricted Rights - Use, duplication or
//* disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
//*
//*-------------------------------------------------------------------
//*
//* The sample contained herein is provided to you "AS IS".
//*
//* It is furnished by IBM as a simple example and has not been thoroughly tested
//* under all conditions.  IBM, therefore, cannot guarantee its reliability,
//* serviceability or functionality.
//*
//*-------------------------------------------------------------------

package com.mycompany.tools.segmentation;

import com.ibm.commerce.condition.Condition;
import com.ibm.commerce.tools.segmentation.SegmentSaveControllerCmdImpl;
import com.ibm.commerce.tools.segmentation.SegmentUtil;

/**
 * This class implements the SegmentSaveControllerCmd interface to
 * provide the controller command that saves a segment.
 * This controller command is mapped to the SegmentSave URL.
 */
public class MySegmentSaveControllerCmdImpl extends SegmentSaveControllerCmdImpl
 {
  /**
   * Constructs an instance of SegmentNotebookDataBean and stores it in _segment.
   */
  protected void constructSegmentNotebookDataBean()
   {
    if (_segment == null)
     {
      _segment = new MySegmentNotebookDataBean();
     }
   }

  /**
   * Populates the vector in _conditionsVector with Condition objects that
   * will be collected together in an AndListCondition object.
   */
  protected void constructConditionsVector()
   {
    super.constructConditionsVector();
    Condition condition = constructBeverageCondition();
    if (condition != null)
     {
      _conditionsVector.addElement(condition);
     }
   }

  /**
   * Constructs the beverage condition object.
   *
   * @return A condition object or null.
   */
  protected Condition constructBeverageCondition()
   {
    return SegmentUtil.constructStringListCondition(((MySegmentNotebookDataBean)_segment).getBeverageOp(),
                                                    ((MySegmentNotebookDataBean)_segment).getBeverageValues(),
                                                    "beverage");
   }
 }
